import rthemelib.plugin_manager as pm
import rthemelib.theme_classes as tc
import os

HOME_ = os.path.expanduser('~')
CSS_FILE_ = f"{HOME_}/.config/gtk-4.0/gtk.css"
CSS_DIR_ = f"{HOME_}/.config/gtk-4.0/"


class Plugin(pm.Plugin):
    def __init__(self, plugin_manager: pm.PluginManager):
        super().__init__(plugin_manager)
        self.name = "gtk4"
        self.description = "A plugin for GTK4/Libadwaita themes."
        self.version = "0.1"
        self.author = "PizzaLovingNerd"
        self.plugin_properties = ["custom_css"]

    def on_load(self):  # Runs when the plugin is loaded
        print("GTK4 Plugin Loaded")

    def purge_theme(self):  # Purges the theme.
        if os.path.exists(CSS_FILE_):
            os.remove(CSS_FILE_)

    def apply_theme(self, subvariant: tc.Subvariant):  # Ran when applying a theme.
        self.purge_theme()
        # If the theme is Adwaita, we don't need to do anything.
        if subvariant.parent_variant.theme.name.lower() == "adwaita":
            return
        if not os.path.exists(CSS_DIR_):
            os.mkdir(CSS_DIR_)

        lines = [
            "/* AUTOGENERATED BY RTHEME, DO NOT EDIT WITHOUT RUNNING \"rthemed disable\"",
            "OTHERWISE IT MAY BE OVERWRITTEN BY RTHEMED */", ""
        ]
        for items in subvariant.properties.items():
            lines.append(f"@define-color {items[0]} {items[1]};")
        if "gtk3" in subvariant.plugin_properties:
            lines.append("")
            lines.append("/* Custom CSS */")
            for item in subvariant.plugin_properties["gtk4"]["custom_css"].splitlines():
                lines.append(item)
            lines.append("")
        for line in lines:
            with open(CSS_FILE_, "a") as f:
                f.write(f"{line}\n")
        print("GTK4 theme applied.")
